[Scummvm-git-logs] scummvm master -> dfa2bd8346f8437370c40c11d4f8820d1d645585

OMGPizzaGuy noreply at scummvm.org
Sat May 16 00:54:58 UTC 2026


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://api.github.com/repos/scummvm/scummvm .

Summary:
dfa2bd8346 TEST: Fix CxxTest::ErrorPrinter with --no-std


Commit: dfa2bd8346f8437370c40c11d4f8820d1d645585
    https://github.com/scummvm/scummvm/commit/dfa2bd8346f8437370c40c11d4f8820d1d645585
Author: Matthew Jimenez (matthew.jimenez at outlook.com)
Date: 2026-05-15T19:54:47-05:00

Commit Message:
TEST: Fix CxxTest::ErrorPrinter with --no-std

Changed paths:
    test/cxxtest/cxxtest/ErrorPrinter.h
    test/cxxtest/cxxtest/MSVCErrorPrinter.h
    test/cxxtest/cxxtest/ParenPrinter.h


diff --git a/test/cxxtest/cxxtest/MSVCErrorPrinter.h b/test/cxxtest/cxxtest/MSVCErrorPrinter.h
index 845d7041d26..21a41bf94ba 100644
--- a/test/cxxtest/cxxtest/MSVCErrorPrinter.h
+++ b/test/cxxtest/cxxtest/MSVCErrorPrinter.h
@@ -32,7 +32,7 @@ namespace CxxTest
 class MSVCErrorPrinter : public ErrorPrinter
 {
 public:
-    MSVCErrorPrinter(CXXTEST_STD(ostream) &o = CXXTEST_STD(cout))
+    MSVCErrorPrinter(FILE *o = stdout)
         : ErrorPrinter(o, "(", ") ", "error C2999", "warning C4999") {}
 };
 }
diff --git a/test/cxxtest/cxxtest/ParenPrinter.h b/test/cxxtest/cxxtest/ParenPrinter.h
index 3a114af6591..6485c941496 100644
--- a/test/cxxtest/cxxtest/ParenPrinter.h
+++ b/test/cxxtest/cxxtest/ParenPrinter.h
@@ -25,7 +25,7 @@ namespace CxxTest
 class ParenPrinter : public ErrorPrinter
 {
 public:
-    ParenPrinter(CXXTEST_STD(ostream) &o = CXXTEST_STD(cout)) : ErrorPrinter(o, "(", ")") {}
+    ParenPrinter(FILE *o = stdout) : ErrorPrinter(o, "(", ")") {}
 };
 }
 




More information about the Scummvm-git-logs mailing list
diff --git a/test/cxxtest/cxxtest/ErrorPrinter.h b/test/cxxtest/cxxtest/ErrorPrinter.h
index 8d5b172539b..3b6c237d46c 100644
--- a/test/cxxtest/cxxtest/ErrorPrinter.h
+++ b/test/cxxtest/cxxtest/ErrorPrinter.h
@@ -16,30 +16,18 @@
 // The ErrorPrinter is a simple TestListener that
 // just prints "OK" if everything goes well, otherwise
 // reports the error in the format of compiler messages.
 // The ErrorPrinter uses std::cout
 //
 
-#include <cxxtest/Flags.h>
-
-#ifndef _CXXTEST_HAVE_STD
-#   define _CXXTEST_HAVE_STD
-#endif // _CXXTEST_HAVE_STD
-
 #include <cxxtest/ErrorFormatter.h>
-#include <cxxtest/StdValueTraits.h>
-
-#ifdef _CXXTEST_OLD_STD
-#   include <iostream.h>
-#else // !_CXXTEST_OLD_STD
-#   include <iostream>
-#endif // _CXXTEST_OLD_STD
+#include <stdio.h>
 
 namespace CxxTest
 {
 class ErrorPrinter : public ErrorFormatter
 {
 public:
-    ErrorPrinter(CXXTEST_STD(ostream) &o = CXXTEST_STD(cout), const char *preLine = ":", const char *postLine = "",
+    ErrorPrinter(FILE *o = stdout, const char *preLine = ":", const char *postLine = "",
                  const char *errorString = "Error",
                  const char *warningString = "Warning") :
         ErrorFormatter(new Adapter(o), preLine, postLine, errorString, warningString) {}
@@ -48,19 +36,17 @@ public:
 private:
     class Adapter : public OutputStream
     {
-        CXXTEST_STD(ostream) &_o;
+        Adapter(const Adapter &);
+        Adapter &operator=(const Adapter &);
+
+        FILE *_o;
+
     public:
-        Adapter(CXXTEST_STD(ostream) &o) : _o(o) {}
-        void flush() { _o.flush(); }
-        OutputStream &operator<<(const char *s) { _o << s; return *this; }
+        Adapter(FILE *o) : _o(o) {}
+        void flush() { fflush(_o); }
+        OutputStream &operator<<(unsigned i) { fprintf(_o, "%u", i); return *this; }
+        OutputStream &operator<<(const char *s) { fputs(s, _o); return *this; }
         OutputStream &operator<<(Manipulator m) { return OutputStream::operator<<(m); }
-        OutputStream &operator<<(unsigned i)
-        {
-            char s[1 + 3 * sizeof(unsigned)];
-            numberToString(i, s);
-            _o << s;
-            return *this;
-        }
     };
 };
 }
@@ -16,30 +16,18 @@
 // just prints "OK" if everything goes well, otherwise
 // reports the error in the format of compiler messages.
-// The ErrorPrinter uses std::cout
+// The ErrorPrinter uses stdout
 //
 